@@ -1,10 +1,5 @@
-# ovirt-imageio
-# Copyright (C) 2015-2018 Red Hat, Inc.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# SPDX-FileCopyrightText: Red Hat, Inc.
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 from . import configloader
 from .units import MiB
@@ -54,6 +49,10 @@ class daemon:
     # configuration.
     group_name = "ovirtimg"
 
+    # Enable systemd integration. Must be enabled when running via the systemd
+    # daemon and disabled otherwise.
+    systemd_enable = True
+
 
 class tls:
 
@@ -135,6 +134,9 @@ class local:
 
 class control:
 
+    # Enable control service.
+    enable = True
+
     # Transport be used to communicate with control service socket.
     # Can be either "tcp" or "unix". If "unix" is used, communication will
     # be done over UNIX socket which path is specified in "socket" option.
