@@ -1,16 +1,12 @@
-# ovirt-imageio
-# Copyright (C) 2018 Red Hat, Inc.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# SPDX-FileCopyrightText: Red Hat, Inc.
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 import functools
 import json
 import logging
 import os
 import signal
+import stat
 import subprocess
 import urllib.parse
 
@@ -152,7 +148,8 @@ class Server:
         # Build a 'json:{...}' filename allowing control all aspects of the
         # image.
 
-        file = {"driver": "file", "filename": self.image}
+        driver = "host_device" if self._is_block_device() else "file"
+        file = {"driver": driver, "filename": self.image}
 
         if self.offset is not None or self.size is not None:
             # Exposing a range in a raw file.
@@ -243,6 +240,9 @@ class Server:
             os.close(fd)
             return True
 
+    def _is_block_device(self):
+        return stat.S_ISBLK(os.stat(self.image).st_mode)
+
     def _preexec_fn(self):
         """
         Called in the child process just before the child is executed.
