@@ -1,17 +1,16 @@
-# ovirt-imageio
-# Copyright (C) 2015-2016 Red Hat, Inc.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# SPDX-FileCopyrightText: Red Hat, Inc.
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 import collections
 import io
 import mmap
 import os
+import shutil
+import tempfile
 import threading
 
+from contextlib import contextmanager
+
 from .units import KiB
 
 
@@ -113,6 +112,15 @@ def ensure_text(s, encoding='utf-8', errors='strict'):
         raise TypeError("not expecting type '%s'" % type(s))
 
 
+@contextmanager
+def tmp_dir(prefix):
+    path = tempfile.mkdtemp(prefix=prefix)
+    try:
+        yield path
+    finally:
+        shutil.rmtree(path)
+
+
 class UnbufferedStream:
     """
     Unlike regular file object, read may return any amount of bytes up to the
