@@ -1,10 +1,5 @@
-# ovirt-imageio
-# Copyright (C) 2015-2018 Red Hat, Inc.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# SPDX-FileCopyrightText: Red Hat, Inc.
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 import errno
 import io
@@ -44,8 +39,9 @@ KERNEL_VERSION = tuple(map(int, os.uname()[2].split(".")[:2]))
     ids=lambda x: str(x[0]),
 )
 def user_file(request):
-    with storage.Backend(*request.param) as backend:
-        yield backend
+    backend, can_detect_sector_size = request.param
+    with backend:
+        yield storage.Backend(backend, can_detect_sector_size)
 
 
 def test_debugging_interface(user_file):
